@@ -50,7 +50,14 @@ class Execution(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Execution.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["ExecutionProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -161,7 +168,20 @@ class ExecutionProps:
         :param template_version: Property templateVersion: Version number of template. Default to the latest version.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ExecutionProps.__init__)
+            def stub(
+                *,
+                template_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                mode: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                parameters: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]] = None,
+                parent_execution_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_options: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosExecution.ResourceOptionsProperty", typing.Dict[str, typing.Any]]]] = None,
+                safety_check: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                template_version: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
             check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
@@ -310,7 +330,14 @@ class Parameter(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Parameter.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["ParameterProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -363,7 +390,17 @@ class ParameterProps:
         :param resource_group_id: Property resourceGroupId: Resource group id.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ParameterProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                constraints: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
@@ -481,7 +518,14 @@ class RosExecution(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosExecution.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosExecutionProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -497,7 +541,9 @@ class RosExecution(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosExecution._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -597,7 +643,9 @@ class RosExecution(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -615,7 +663,11 @@ class RosExecution(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "template_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "templateName", value)
 
@@ -635,7 +687,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "mode").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mode", value)
 
@@ -655,7 +711,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "parameters").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parameters", value)
 
@@ -675,7 +735,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "parent_execution_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parentExecutionId", value)
 
@@ -695,7 +759,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "resource_group_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceGroupId", value)
 
@@ -715,7 +783,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosExecution.ResourceOptionsProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "resource_options").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosExecution.ResourceOptionsProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceOptions", value)
 
@@ -740,7 +812,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "safety_check").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "safetyCheck", value)
 
@@ -758,7 +834,11 @@ class RosExecution(
         value: typing.Optional[typing.Mapping[builtins.str, typing.Any]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "tags").fset)
+            def stub(
+                value: typing.Optional[typing.Mapping[builtins.str, typing.Any]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -778,7 +858,11 @@ class RosExecution(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosExecution, "template_version").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "templateVersion", value)
 
@@ -808,7 +892,15 @@ class RosExecution(
             :param timeout: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosExecution.ResourceOptionsProperty.__init__)
+                def stub(
+                    *,
+                    cancel_on_delete: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                    failure_statuses: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
+                    success_statuses: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
+                    timeout: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument cancel_on_delete", value=cancel_on_delete, expected_type=type_hints["cancel_on_delete"])
                 check_type(argname="argument failure_statuses", value=failure_statuses, expected_type=type_hints["failure_statuses"])
                 check_type(argname="argument success_statuses", value=success_statuses, expected_type=type_hints["success_statuses"])
@@ -928,7 +1020,20 @@ class RosExecutionProps:
         :param template_version: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosExecutionProps.__init__)
+            def stub(
+                *,
+                template_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                mode: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                parameters: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]] = None,
+                parent_execution_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_options: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosExecution.ResourceOptionsProperty, typing.Dict[str, typing.Any]]]] = None,
+                safety_check: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                template_version: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
             check_type(argname="argument mode", value=mode, expected_type=type_hints["mode"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
@@ -1084,7 +1189,14 @@ class RosParameter(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosParameter.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosParameterProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1100,7 +1212,9 @@ class RosParameter(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosParameter._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -1139,7 +1253,9 @@ class RosParameter(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -1158,7 +1274,11 @@ class RosParameter(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -1176,7 +1296,11 @@ class RosParameter(
     @type.setter
     def type(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "type").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
@@ -1197,7 +1321,11 @@ class RosParameter(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "value").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "value", value)
 
@@ -1224,7 +1352,11 @@ class RosParameter(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "constraints").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "constraints", value)
 
@@ -1247,7 +1379,11 @@ class RosParameter(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "description").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -1267,7 +1403,11 @@ class RosParameter(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosParameter, "resource_group_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceGroupId", value)
 
@@ -1305,7 +1445,17 @@ class RosParameterProps:
         :param resource_group_id: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosParameterProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                constraints: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
@@ -1435,7 +1585,14 @@ class RosTemplate(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTemplate.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosTemplateProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1451,7 +1608,9 @@ class RosTemplate(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTemplate._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -1504,7 +1663,11 @@ class RosTemplate(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTemplate, "content").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "content", value)
 
@@ -1516,7 +1679,9 @@ class RosTemplate(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTemplate, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -1534,7 +1699,11 @@ class RosTemplate(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTemplate, "template_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "templateName", value)
 
@@ -1554,7 +1723,11 @@ class RosTemplate(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTemplate, "resource_group_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceGroupId", value)
 
@@ -1572,7 +1745,11 @@ class RosTemplate(
         value: typing.Optional[typing.Mapping[builtins.str, typing.Any]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTemplate, "tags").fset)
+            def stub(
+                value: typing.Optional[typing.Mapping[builtins.str, typing.Any]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -1604,7 +1781,15 @@ class RosTemplateProps:
         :param tags: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTemplateProps.__init__)
+            def stub(
+                *,
+                content: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                template_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument content", value=content, expected_type=type_hints["content"])
             check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
             check_type(argname="argument resource_group_id", value=resource_group_id, expected_type=type_hints["resource_group_id"])
@@ -1692,7 +1877,14 @@ class Template(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["TemplateProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1745,7 +1937,15 @@ class TemplateProps:
         :param tags: Property tags: Tag value and the key mapping, the label of the key number can be up to 20.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TemplateProps.__init__)
+            def stub(
+                *,
+                content: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                template_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument content", value=content, expected_type=type_hints["content"])
             check_type(argname="argument template_name", value=template_name, expected_type=type_hints["template_name"])
             check_type(argname="argument resource_group_id", value=resource_group_id, expected_type=type_hints["resource_group_id"])
